Computes the expected value from a zero-truncated negative binomial (ZTNB) distribution based on the model parameters and covariates.
E_negbin_noinfl(b, a, X)A numeric vector of expected values for each observation in the dataset.
Numeric vector of coefficients for the regression model.
Numeric scalar, the overdispersion parameter of the negative binomial distribution.
Matrix of predictors for the model, where rows correspond to observations and columns to covariates.
dEdq_nb_noinfl for computing partial derivatives of expected values in the ZTNB model.