Computes the expected value from a Poisson (PP) distribution based on the model parameters and covariates.
E_pois_noinfl(b, X)A numeric vector of expected values for each observation in the dataset.
Numeric vector of coefficients for the Poisson model.
Matrix of predictors for the Poisson model, where rows correspond to observations and columns to covariates.
dEdq_pois_noinfl for computing partial derivatives of expected values in the Poisson model.